@@ -1,4 +1,5 @@
 package Bio::Phylo::Parsers::Newick;
+use warnings;
 use strict;
 use base 'Bio::Phylo::Parsers::Abstract';
 no warnings 'recursion';
@@ -17,6 +18,64 @@ don't call it directly.
 
 sub _return_is_scalar { 1 }
 
+
+sub _simplify {
+    # Simplify a Newick tree string by removing unneeded nodes. The leaves to
+    # keep are given as $ids, an arrayref of terminal node IDs. Note that only
+    # cherries are simplified to keep the function fast.
+    my ($string, $ids) = @_;   
+    my %id_hash = map { $_ => undef } @$ids;
+
+    # Setup some regular expressions:
+    # 1/ ID is anything but : or , or ( or )
+    my $id_re     = qr/[^)(:,;]+/;
+    # 2/ Distance is a number (Regexp::Common $RE{num}{real} would be more stringent)
+    my $dist_re   = qr/[0-9.]+/;
+    # 3/ A pair of ID and distance (both optional)
+    my $pair_re   = qr/ ($id_re)? (?: \: ($dist_re) )? /x;
+    # 4/ Cherry
+    my $cherry_re = qr/ ( \( $pair_re , $pair_re \) $pair_re ) /x;
+    # 5/ Whitespaces 
+    my $ws_re     = qr/ \s+ /msx;
+
+    # Remove spaces and newlines (no spaces allowed in node names)
+    $string =~ s/$ws_re//g;
+
+    # Prune cherries
+    my $prev_string = $string;
+    while (1) {
+        $string =~ s/ $cherry_re / _prune_cherry($1, $2, $3, $4, $5, $6, $7, \%id_hash) /gex;
+        last if ( $string eq $prev_string );
+        $prev_string = $string;
+    }
+
+    return $string;
+}
+
+sub _prune_cherry {
+    my ($match, $id1, $dist1, $id2, $dist2, $idp, $distp, $id_hash) = @_;
+    my $repl;
+
+    my $id1_exists = defined $id1 && exists $id_hash->{$id1};
+    my $id2_exists = defined $id2 && exists $id_hash->{$id2};
+    if (          $id1_exists  &&     $id2_exists  ) {
+        # Keep both leaves
+        $repl = $match;
+    } elsif ( not($id1_exists) && not($id2_exists) ) {
+        # Delete both leaves
+        $repl = '';
+    } else {
+        # Keep only one leaf
+        my ($id, $dist) = $id1_exists ? ($id1, $dist1) : ($id2, $dist2);
+        if ( defined($dist) || defined($distp) ) {
+            $dist = ':'.(($dist||0) + ($distp||0));
+        }
+        $dist = '' if not defined $dist;
+        $repl = $id.$dist;
+    }
+    return $repl;
+}
+
 sub _parse {
     my $self   = shift;
     my $fh     = $self->_handle;
@@ -27,9 +86,16 @@ sub _parse {
         $string .= $_;
     }
 
+    my $ids = $self->_args->{'-keep'};
+
     # remove comments, split on tree descriptions
     for my $newick ( $self->_split($string) ) {
 
+        # simplify tree
+        if ($ids) {
+            $newick = _simplify($string, $ids);
+        }
+
         # parse trees
         my $tree = $self->_parse_string($newick);
 
